<?php


namespace Sample;


use ESET\SecureAuthentication\SDK\IUserStorage;

class CustomUserStorage implements IUserStorage
{
    /** @var  string Filename used to store user data */
    private $filename;

    /** @var  array Associative array containing user data */
    private $dataStore;

    public function __construct($filename)
    {
        $this->filename = $filename;
        $this->dataStore = array();
    }



    /**
     * Load the two-factor authentication data for a user
     * @param $username string
     * @return string
     */
    public function loadUser($username)
    {
        $this->loadFile();

        if (array_key_exists($username, $this->dataStore)) {
            return $this->dataStore[$username];

        } else {
            return null;
        }
    }

    /**
     * Save the two-factor authentication data for a user
     * @param $username string
     * @param $data string
     * @return void
     */
    public function saveUser($username, $data)
    {
        $this->dataStore[$username] = $data;
        $this->saveFile();
    }




    /**
     * Load our data from the filesystem
     */
    private function loadFile()
    {
        if (file_exists($this->filename)) {
            $fileContents = file_get_contents($this->filename);
            $this->dataStore = unserialize($fileContents);

        } else {
            $this->dataStore = array();
        }
    }

    /**
     * Save our data to the filesystem
     */
    private function saveFile()
    {
        $fileContents = serialize($this->dataStore);
        file_put_contents($this->filename, $fileContents);
    }
}
